==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/sagemaker_endpoint/SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicy.java <==
package com.hashicorp.cdktf.providers.aws.sagemaker_endpoint;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:55.487Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.sagemakerEndpoint.SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicy")
@software.amazon.jsii.Jsii.Proxy(SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicy.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicy extends software.amazon.jsii.JsiiSerializable {

    /**
     * traffic_routing_configuration block.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint#traffic_routing_configuration SagemakerEndpoint#traffic_routing_configuration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.sagemaker_endpoint.SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicyTrafficRoutingConfiguration getTrafficRoutingConfiguration();

    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint#maximum_execution_timeout_in_seconds SagemakerEndpoint#maximum_execution_timeout_in_seconds}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Number getMaximumExecutionTimeoutInSeconds() {
        return null;
    }

    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint#termination_wait_in_seconds SagemakerEndpoint#termination_wait_in_seconds}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Number getTerminationWaitInSeconds() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicy}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicy}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicy> {
        com.hashicorp.cdktf.providers.aws.sagemaker_endpoint.SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicyTrafficRoutingConfiguration trafficRoutingConfiguration;
        java.lang.Number maximumExecutionTimeoutInSeconds;
        java.lang.Number terminationWaitInSeconds;

        /**
         * Sets the value of {@link SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicy#getTrafficRoutingConfiguration}
         * @param trafficRoutingConfiguration traffic_routing_configuration block. This parameter is required.
         *                                    Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint#traffic_routing_configuration SagemakerEndpoint#traffic_routing_configuration}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder trafficRoutingConfiguration(com.hashicorp.cdktf.providers.aws.sagemaker_endpoint.SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicyTrafficRoutingConfiguration trafficRoutingConfiguration) {
            this.trafficRoutingConfiguration = trafficRoutingConfiguration;
            return this;
        }

        /**
         * Sets the value of {@link SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicy#getMaximumExecutionTimeoutInSeconds}
         * @param maximumExecutionTimeoutInSeconds Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint#maximum_execution_timeout_in_seconds SagemakerEndpoint#maximum_execution_timeout_in_seconds}.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder maximumExecutionTimeoutInSeconds(java.lang.Number maximumExecutionTimeoutInSeconds) {
            this.maximumExecutionTimeoutInSeconds = maximumExecutionTimeoutInSeconds;
            return this;
        }

        /**
         * Sets the value of {@link SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicy#getTerminationWaitInSeconds}
         * @param terminationWaitInSeconds Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint#termination_wait_in_seconds SagemakerEndpoint#termination_wait_in_seconds}.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder terminationWaitInSeconds(java.lang.Number terminationWaitInSeconds) {
            this.terminationWaitInSeconds = terminationWaitInSeconds;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicy}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicy build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicy}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicy {
        private final com.hashicorp.cdktf.providers.aws.sagemaker_endpoint.SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicyTrafficRoutingConfiguration trafficRoutingConfiguration;
        private final java.lang.Number maximumExecutionTimeoutInSeconds;
        private final java.lang.Number terminationWaitInSeconds;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.trafficRoutingConfiguration = software.amazon.jsii.Kernel.get(this, "trafficRoutingConfiguration", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.sagemaker_endpoint.SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicyTrafficRoutingConfiguration.class));
            this.maximumExecutionTimeoutInSeconds = software.amazon.jsii.Kernel.get(this, "maximumExecutionTimeoutInSeconds", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.terminationWaitInSeconds = software.amazon.jsii.Kernel.get(this, "terminationWaitInSeconds", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.trafficRoutingConfiguration = java.util.Objects.requireNonNull(builder.trafficRoutingConfiguration, "trafficRoutingConfiguration is required");
            this.maximumExecutionTimeoutInSeconds = builder.maximumExecutionTimeoutInSeconds;
            this.terminationWaitInSeconds = builder.terminationWaitInSeconds;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.sagemaker_endpoint.SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicyTrafficRoutingConfiguration getTrafficRoutingConfiguration() {
            return this.trafficRoutingConfiguration;
        }

        @Override
        public final java.lang.Number getMaximumExecutionTimeoutInSeconds() {
            return this.maximumExecutionTimeoutInSeconds;
        }

        @Override
        public final java.lang.Number getTerminationWaitInSeconds() {
            return this.terminationWaitInSeconds;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("trafficRoutingConfiguration", om.valueToTree(this.getTrafficRoutingConfiguration()));
            if (this.getMaximumExecutionTimeoutInSeconds() != null) {
                data.set("maximumExecutionTimeoutInSeconds", om.valueToTree(this.getMaximumExecutionTimeoutInSeconds()));
            }
            if (this.getTerminationWaitInSeconds() != null) {
                data.set("terminationWaitInSeconds", om.valueToTree(this.getTerminationWaitInSeconds()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.sagemakerEndpoint.SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicy"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicy.Jsii$Proxy that = (SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicy.Jsii$Proxy) o;

            if (!trafficRoutingConfiguration.equals(that.trafficRoutingConfiguration)) return false;
            if (this.maximumExecutionTimeoutInSeconds != null ? !this.maximumExecutionTimeoutInSeconds.equals(that.maximumExecutionTimeoutInSeconds) : that.maximumExecutionTimeoutInSeconds != null) return false;
            return this.terminationWaitInSeconds != null ? this.terminationWaitInSeconds.equals(that.terminationWaitInSeconds) : that.terminationWaitInSeconds == null;
        }

        @Override
        public final int hashCode() {
            int result = this.trafficRoutingConfiguration.hashCode();
            result = 31 * result + (this.maximumExecutionTimeoutInSeconds != null ? this.maximumExecutionTimeoutInSeconds.hashCode() : 0);
            result = 31 * result + (this.terminationWaitInSeconds != null ? this.terminationWaitInSeconds.hashCode() : 0);
            return result;
        }
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/sagemaker_endpoint/SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicy.java <==
package com.hashicorp.cdktf.providers.aws.sagemaker_endpoint;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:11.573Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.sagemakerEndpoint.SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicy")
@software.amazon.jsii.Jsii.Proxy(SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicy.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicy extends software.amazon.jsii.JsiiSerializable {

    /**
     * traffic_routing_configuration block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/sagemaker_endpoint#traffic_routing_configuration SagemakerEndpoint#traffic_routing_configuration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.sagemaker_endpoint.SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicyTrafficRoutingConfiguration getTrafficRoutingConfiguration();

    /**
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/sagemaker_endpoint#maximum_execution_timeout_in_seconds SagemakerEndpoint#maximum_execution_timeout_in_seconds}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Number getMaximumExecutionTimeoutInSeconds() {
        return null;
    }

    /**
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/sagemaker_endpoint#termination_wait_in_seconds SagemakerEndpoint#termination_wait_in_seconds}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Number getTerminationWaitInSeconds() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicy}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicy}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicy> {
        com.hashicorp.cdktf.providers.aws.sagemaker_endpoint.SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicyTrafficRoutingConfiguration trafficRoutingConfiguration;
        java.lang.Number maximumExecutionTimeoutInSeconds;
        java.lang.Number terminationWaitInSeconds;

        /**
         * Sets the value of {@link SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicy#getTrafficRoutingConfiguration}
         * @param trafficRoutingConfiguration traffic_routing_configuration block. This parameter is required.
         *                                    Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/sagemaker_endpoint#traffic_routing_configuration SagemakerEndpoint#traffic_routing_configuration}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder trafficRoutingConfiguration(com.hashicorp.cdktf.providers.aws.sagemaker_endpoint.SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicyTrafficRoutingConfiguration trafficRoutingConfiguration) {
            this.trafficRoutingConfiguration = trafficRoutingConfiguration;
            return this;
        }

        /**
         * Sets the value of {@link SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicy#getMaximumExecutionTimeoutInSeconds}
         * @param maximumExecutionTimeoutInSeconds Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/sagemaker_endpoint#maximum_execution_timeout_in_seconds SagemakerEndpoint#maximum_execution_timeout_in_seconds}.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder maximumExecutionTimeoutInSeconds(java.lang.Number maximumExecutionTimeoutInSeconds) {
            this.maximumExecutionTimeoutInSeconds = maximumExecutionTimeoutInSeconds;
            return this;
        }

        /**
         * Sets the value of {@link SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicy#getTerminationWaitInSeconds}
         * @param terminationWaitInSeconds Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/sagemaker_endpoint#termination_wait_in_seconds SagemakerEndpoint#termination_wait_in_seconds}.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder terminationWaitInSeconds(java.lang.Number terminationWaitInSeconds) {
            this.terminationWaitInSeconds = terminationWaitInSeconds;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicy}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicy build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicy}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicy {
        private final com.hashicorp.cdktf.providers.aws.sagemaker_endpoint.SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicyTrafficRoutingConfiguration trafficRoutingConfiguration;
        private final java.lang.Number maximumExecutionTimeoutInSeconds;
        private final java.lang.Number terminationWaitInSeconds;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.trafficRoutingConfiguration = software.amazon.jsii.Kernel.get(this, "trafficRoutingConfiguration", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.sagemaker_endpoint.SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicyTrafficRoutingConfiguration.class));
            this.maximumExecutionTimeoutInSeconds = software.amazon.jsii.Kernel.get(this, "maximumExecutionTimeoutInSeconds", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.terminationWaitInSeconds = software.amazon.jsii.Kernel.get(this, "terminationWaitInSeconds", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.trafficRoutingConfiguration = java.util.Objects.requireNonNull(builder.trafficRoutingConfiguration, "trafficRoutingConfiguration is required");
            this.maximumExecutionTimeoutInSeconds = builder.maximumExecutionTimeoutInSeconds;
            this.terminationWaitInSeconds = builder.terminationWaitInSeconds;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.sagemaker_endpoint.SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicyTrafficRoutingConfiguration getTrafficRoutingConfiguration() {
            return this.trafficRoutingConfiguration;
        }

        @Override
        public final java.lang.Number getMaximumExecutionTimeoutInSeconds() {
            return this.maximumExecutionTimeoutInSeconds;
        }

        @Override
        public final java.lang.Number getTerminationWaitInSeconds() {
            return this.terminationWaitInSeconds;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("trafficRoutingConfiguration", om.valueToTree(this.getTrafficRoutingConfiguration()));
            if (this.getMaximumExecutionTimeoutInSeconds() != null) {
                data.set("maximumExecutionTimeoutInSeconds", om.valueToTree(this.getMaximumExecutionTimeoutInSeconds()));
            }
            if (this.getTerminationWaitInSeconds() != null) {
                data.set("terminationWaitInSeconds", om.valueToTree(this.getTerminationWaitInSeconds()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.sagemakerEndpoint.SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicy"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicy.Jsii$Proxy that = (SagemakerEndpointDeploymentConfigBlueGreenUpdatePolicy.Jsii$Proxy) o;

            if (!trafficRoutingConfiguration.equals(that.trafficRoutingConfiguration)) return false;
            if (this.maximumExecutionTimeoutInSeconds != null ? !this.maximumExecutionTimeoutInSeconds.equals(that.maximumExecutionTimeoutInSeconds) : that.maximumExecutionTimeoutInSeconds != null) return false;
            return this.terminationWaitInSeconds != null ? this.terminationWaitInSeconds.equals(that.terminationWaitInSeconds) : that.terminationWaitInSeconds == null;
        }

        @Override
        public final int hashCode() {
            int result = this.trafficRoutingConfiguration.hashCode();
            result = 31 * result + (this.maximumExecutionTimeoutInSeconds != null ? this.maximumExecutionTimeoutInSeconds.hashCode() : 0);
            result = 31 * result + (this.terminationWaitInSeconds != null ? this.terminationWaitInSeconds.hashCode() : 0);
            return result;
        }
    }
}
